@@ -1,5 +1,5 @@
 /** -*- mode: c++ ; c-basic-offset: 2 -*-
- * @file   WebcamGrabber.h
+ * @file   WebcamSource.h
  * @author Sebastien Fourey
  * @date   July 2010
  * @brief  Declaration of the class ImageFilter
@@ -55,9 +55,9 @@
 #include <cv.h>
 #include <highgui.h>
 #endif
-#include <QVector>
 #include <QList>
 #include <QSize>
+#include <QVector>
 #include "ImageSource.h"
 
 class QSplashScreen;
@@ -69,7 +69,7 @@ public:
   ~WebcamSource();
   int cameraIndex();
   void capture();
-  void setCameraIndex( int i );
+  void setCameraIndex(int i);
   void stop();
   void start();
   QSize captureSize();
@@ -77,15 +77,18 @@ public:
   void setCaptureSize(const QSize & size);
   static const QList<int> & getWebcamList();
   static const QList<int> & getCachedWebcamList();
+  static int getFirstUnusedWebcam();
+  static bool isWebcamUnused(int index);
   static void retrieveWebcamResolutions(const QList<int> & camList, QSplashScreen * splashScreen = 0, QStatusBar * statusBar = 0);
   static const QList<QSize> & webcamResolutions(int index);
   static void clearSavedSettings();
+
 private:
-  CvCapture *_capture;
+  CvCapture * _capture;
   int _cameraIndex;
   QSize _captureSize;
   static QList<int> _webcamList;
-  static QVector< QList<QSize> > _webcamResolutions;
+  static QVector<QList<QSize>> _webcamResolutions;
 };
 
 #endif
